@@ -28,22 +28,12 @@ elas.frontierQuad <- function( object, data = NULL, dataLogged = TRUE,
 
    if( dataLogged ) {
       # translog function
-      if( !object$logDepVar ) {
-         stop( "a translog function must have a logged dependent variable",
-            " but the model was estimated with argument 'logDepVar'",
-            " equal to 'FALSE'" )
-      }
       result <- translogEla( xNames = xNames, data = data,
          coef = coef( object )[ 1:nCoef ],
          coefCov = vcov( object )[ 1:nCoef, 1:nCoef ],
          quadHalf = quadHalf, dataLogged = TRUE )
    } else {
       # quadratic function
-      if( object$logDepVar ) {
-         stop( "a quadratic function must NOT have a logged dependent variable",
-            " but the model was estimated with argument 'logDepVar'",
-            " equal to 'TRUE'" )
-      }
       stop( "sorry, the calculation of elasticities of a quadratic function",
          " is not implemented yet" )
    }
